
import { alert, goLink, isEmptyObject, retrieval } from "@/common/common";
import Popup from "@/components/popup";
import { Button, Image, Text, Textarea, View } from "@tarojs/components"
import Taro, { chooseMedia } from "@tarojs/taro";
import { GetAdminUserInfoApi, realNameUpdateApi } from "@/api/user";
import { memo, useCallback, useEffect, useState } from "react"
import "./index.scss"

export default ()=>{
	// 用户信息
	const { fetchData, state } = GetAdminUserInfoApi();
	const getData = async ()=>{
		const result = await fetchData();
    setFormData({
      ...formData,
      real_name: result.data.user_name
    })
	}
  useEffect(()=>{
    getData();
  },[])
  // 表单数据
  const [formData, setFormData] = useState({
    real_name: "麦兜"
  });
  // 显示popup
  const [popupShow,setPopupShow] = useState(false);
  const triggerList = useCallback((key:string)=>{
    setPopupShow(true);
  },[])
  // popup保存
	const { fetchData: realNameUpdateFetch } = realNameUpdateApi();
  const rules = {
    real_name: [{
      message: "请输入昵称"
    }]
  }
  const handleTextareaSave = async (real_name)=>{
    retrieval({real_name},rules).then(async ()=>{
      const result = await realNameUpdateFetch({real_name});
      if(result.success){
        getData();
        setPopupShow(false);
        alert.success("保存成功");
      }else{
        alert.none(result.msg);
      }
    }).catch(message=>{
      alert.none(message);
    })
  }
  // Taro.eventCenter.on('message:detail', (message) => console.log(message))
  // 面面跳转
  const onNavigate = (url:string)=>{
    goLink(url);
  }
  // 肖像编辑
  const handleSelectRortrait = ()=>{
    chooseMedia({
      count: 1,
      mediaType: ["image"],
      success(ev){
        console.log(ev);
        
      }
    })
  }

  return (
    <View className="user-edit">
      <View onClick={handleSelectRortrait} className="user-edit-portrait">
        <Image src="https://gimg2.baidu.com/image_search/src=http%3A%2F%2Fimg.jj20.com%2Fup%2Fallimg%2F1113%2F052420110515%2F200524110515-2-1200.jpg&refer=http%3A%2F%2Fimg.jj20.com&app=2002&size=f9999,10000&q=a80&n=0&g=0n&fmt=auto?sec=1652840455&t=6d2fd53931578ef6e213a929a77d059c"/>
        <View>点击编辑头像</View>
      </View>
      <View className="user-edit-content">
        <View className="user-edit-content-title"><Text/> 个人资料</View>
        <UserEditList onClick={()=>triggerList('real_name')} data={state.data.user_name} label="昵称" placeholder="请输入" icon=""/>
        <UserEditList onClick={()=>onNavigate("/pages/company/index")} label="手机号" placeholder="去绑定" icon=""/>
      </View>
      <View className="user-edit-content">
        <View className="user-edit-content-title"><Text/> 组织资料</View>
        <UserEditList onClick={()=>triggerList('real_name')} data={state.data.user_name} label="名称" placeholder="待绑定" icon=""/>
        <UserEditList onClick={()=>onNavigate("/pages/company/index")} label="类型" placeholder="完善公司/组织信息" icon=""/>
        <UserEditList onClick={()=>onNavigate("/pages/certification/index")} label="我的认证" placeholder="待绑定" icon="">
          已认证
        </UserEditList>
        <UserEditList onClick={()=>onNavigate("/pages/weightList/index")} label="创建人" placeholder="完善公司/组织信息" icon=""/>
      </View>
      <Button hoverClass="none" className="user-edit-logout">退出当前账号</Button>

      <PopupContent value={formData.real_name} show={popupShow} setPopupShow={setPopupShow} save={handleTextareaSave}/>
    </View>
  )
}

// 列表
const UserEditList = memo((props:any)=>{
  return (
    <View onClick={props.onClick} className="user-edit-list">
      <View className="user-edit-list-left">
        {props.label}
      </View>
      <View className="user-edit-list-right">
        <View>
          {
            props.children?props.children:
            props.data?props.data:
            <View className="user-edit-list-right-placeholder">{props.placeholder}</View>
          }
        </View>
        <Text className="iconfont icon-a-moreback"></Text>
      </View>
    </View>
  )
})

// popup内容
const PopupContent = memo((props:any)=>{
  const [value, setValue] = useState("");
  useEffect(()=>{
    setValue(props.value);
  },[props.value])
  // popup输入长度
  const handleTextareaInput = (ev:any)=>{
    setValue(ev.detail.value.slice(0,20));
  }
  // 重置
  const handleTextareaReset = ()=>{
    setValue("");
  }
  return (
    <Popup onClose={()=>props.setPopupShow(false)} title="修改昵称" show={props.show}>
        <View className="user-edit-popup-content">
          <View className="user-edit-popup-input">
            <Textarea value={value} onInput={handleTextareaInput} maxlength={20}/>
            <Text>{value.length}/20</Text>
          </View>
          <Text className="user-edit-popup-tips">请设置2-20个字符，由中文、英文、数字、-和_组成</Text>
          <View className="user-edit-popup-operation">
            <Button onClick={handleTextareaReset} hoverClass="none" className="user-edit-popup-operation-reset">重置</Button>
            <Button onClick={()=>props.save(value)} hoverClass="none" className="user-edit-popup-operation-save">保存</Button>
          </View>
        </View>
      </Popup>
  )
})